Liepack Module
==============

.. module:: beluga.liepack

Introduction
------------

Stuff to help with Lie theory.

Domains
-------

Various domains are provided to solve equations on.

.. toctree::
    :maxdepth: 1

    domain/liealgebras.rst
    domain/liegroups.rst
    domain/hspaces.rst


Base Class Reference
--------------------

.. autofunction:: algebra2group

.. autofunction:: group2algebra

.. autofunction:: Adjoint

.. autofunction:: commutator

.. autofunction:: dexpinv

.. autofunction:: exp
